@@ -73,7 +73,6 @@ import requests
 import numpy as np
 
 from .proplist import prop2abr, abr2prop
-from .proplist import *
 from .version import __version__
 
 __license__   = "MIT"
@@ -110,6 +109,19 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     :raises pyilt2.queryError: if the database returns an Error on a query
     """
 
+    proplistUrl = 'https://ilthermo.boulder.nist.gov/ILT2/ilprpls'
+
+    r = requests.get(proplistUrl)
+    prpDict = r.json()
+
+    prpNames = []
+    prpKeys = []
+    for pcls in prpDict['plist']:
+        pcls['name'] = map(str.strip, pcls['name'])
+        prpNames += pcls['name']
+        prpKeys += pcls['key']
+    prop2key = dict(zip(prpNames, prpKeys))
+
     #JOAO
     if prop:
         if prop not in prop2key.keys():
